# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Devel-Cycle
Version:	1.12
Release:	11.%{__distinit}%{__distvers}
Summary:	Find memory cycles in objects
License:	GPL+ or Artistic
URL:		https://metacpan.org/release/Devel-Cycle
Source0:	https://cpan.metacpan.org/authors/id/L/LD/LDS/Devel-Cycle-%{version}.tar.gz
Patch0:		Devel-Cycle-1.11-512.patch
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(Carp)
BuildRequires:	perl(constant)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(PadWalker) >= 1.0
BuildRequires:	perl(Scalar::Util)
BuildRequires:	perl(strict)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(overload)
BuildRequires:	perl(Test::More)
# Dependencies
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
Requires:	perl(PadWalker) >= 1.0

%description
This is a simple developer's tool for finding circular references in
objects and other types of references. Because of Perl's reference-count
based memory management, circular references will cause memory leaks.

%prep
%setup -q -n Devel-Cycle-%{version}

# Fix a Perl 5.12 incompatibility (#757274, CPAN RT#56681)
%patch0 -p1

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%doc Changes README
%{perl_vendorlib}/Devel/
%{_mandir}/man3/Devel::Cycle.3*

%changelog
* Mon Nov 19 2018 Paul Howarth <paul@city-fan.org> - 1.12-11
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Don't run release tests whilst bootstrapping
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
- Switch upstream from search.cpan.org to metacpan.org

* Wed Aug 17 2016 Paul Howarth <paul@city-fan.org> - 1.12-5
- BR: perl-generators where available
- Simplify find command using -delete

* Fri Nov 14 2014 Paul Howarth <paul@city-fan.org> - 1.12-1
- Update to 1.12
  - Moved to GitHub at https://github.com/lstein/Devel-Cycle
- Classify buildreqs by usage

* Thu Aug 28 2014 Paul Howarth <paul@city-fan.org> - 1.11-17
- Drop %%defattr, redundant since rpm 4.4

* Wed Jun 20 2012 Paul Howarth <paul@city-fan.org> - 1.11-10
- BR: perl(constant) and perl(Exporter)
- Use PadWalker unconditionally
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Mon Nov 28 2011 Paul Howarth <paul@city-fan.org> - 1.11-9
- Fix a Perl 5.12 incompatibility (#757274, CPAN RT#56681)
- BR: perl(Carp)

* Thu Jun 23 2011 Paul Howarth <paul@city-fan.org> - 1.11-8
- Rebuild for perl 5.14.1 in Rawhide
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Fri Mar  4 2011 Paul Howarth <paul@city-fan.org> - 1.11-7
- Import from Fedora

* Tue Feb  8 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.11-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Thu Dec 16 2010 Marcela Maslanova <mmaslano@redhat.com> - 1.11-5
- Rebuild to fix problems with vendorarch/lib (#661697)

* Fri Apr 30 2010 Marcela Maslanova <mmaslano@redhat.com> - 1.11-4
- Mass rebuild with perl-5.12.0

* Fri Apr 30 2010 Marcela Maslanova <mmaslano@redhat.com> - 1.11-3
- Mass rebuild with perl-5.12.0

* Mon Dec  7 2009 Stepan Kasal <skasal@redhat.com> - 1.11-2
- Rebuild against perl 5.10.1

* Mon Oct  5 2009 Stepan Kasal <skasal@redhat.com> - 1.11-1
- New upstream version

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.10-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.10-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Tue Jul 15 2008 Steven Pritchard <steve@kspei.com> 1.10-1
- Update to 1.10

* Thu May 15 2008 Steven Pritchard <steve@kspei.com> 1.09-1
- Update to 1.09
- Reformat to match cpanspec output
- Fix find option order
- Use fixperms macro instead of our own chmod incantation

* Wed Feb 27 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.07-3
- Rebuild for perl 5.10 (again)

* Sun Jan 13 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.07-2
- Rebuild for new perl

* Mon Oct 15 2007 Tom "spot" Callaway <tcallawa@redhat.com> - 1.07-1.2
- Add BR: perl(Test::More)

* Mon Oct 15 2007 Tom "spot" Callaway <tcallawa@redhat.com> - 1.07-1.1
- Correct license tag
- add BR: perl(ExtUtils::MakeMaker)

* Wed May 24 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.07-1
- Update to 1.07
- Requirement version: perl(PadWalker) >= 1.0

* Mon May 22 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.05-1
- Update to 1.05
- New requirement: perl(PadWalker)

* Thu Feb 16 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.04-4
- Rebuild for FC5 (perl 5.8.8)

* Sat May 14 2005 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.04-3
- Add dist tag

* Mon May  2 2005 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.04-2
- Update to 1.04

* Fri Apr 22 2005 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.03-2
- Fedora Extras: FC-4 version

* Mon Jan 24 2005 Jose Pedro Oliveira <jpo at di.uminho.pt> - 0:1.03-0.fdr.1
- Update to 1.03

* Sun Jul  4 2004 Jose Pedro Oliveira <jpo at di.uminho.pt> - 0:1.02-0.fdr.1
- First build
